# Virgil

[![PyPI version](https://img.shields.io/pypi/v/virgil?color=blue&label=pypi%20package)](https://pypi.org/project/virgil/)
[![Python 3.7+](https://img.shields.io/badge/python-3.7+-blue.svg)](https://www.python.org/downloads/)
[![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/QuicksilverMachine/virgil/blob/master/LICENSE)

Virgil is a dependency management library
